=======================================
``psyclone.psyir.nodes.file_container``
=======================================

.. automodule:: psyclone.psyir.nodes.file_container

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.file_container


Classes
=======

- :py:class:`FileContainer`:
  PSyIR node to encapsulate the scope of a source file. In the


.. autoclass:: FileContainer
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: FileContainer
      :parts: 1
